// Pirate.cpp: implementation of the Pirate class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "Sprite.h"
#include "Texture.h"
#include "Knife.h"
#include "Pirate.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

Pirate::Pirate()
{
	attackTimer = 2;
}

Pirate::~Pirate()
{

}

int Pirate::GetType()
{
	return 3;
}

int Pirate::Move(float xPos, float yPos)
{
	//Move towards random point
	float xDist = destX - sprite.xPos;
	float yDist = destY - sprite.yPos;
	float mag = sqrt(xDist*xDist + yDist*yDist);
	//Invert U coordinate if necessary
	if(destX > sprite.xPos)
	{
		sprite.texture.uMax = -1;
	}else{
		sprite.texture.uMax = 1;
	}
	//Change the point if it has been reached
	if(mag < speed * m)
	{
		sprite.xPos = destX;
		sprite.yPos = destY;
		destX = (rand() % 180) - 90;
		destY = (rand() % 180) - 90;
	}else{
		//Move
		xDist /= mag;
		yDist /= mag;
		mag = 1;
		sprite.xPos += xDist * speed * m;
		sprite.yPos += yDist * speed * m;
	}

	if(attackTimer < 0)
	{
		//Create a knife and reset the attack timer
		attackTimer = 1;
		Knife* k = new Knife;
		k->monsters = monsters;
		k->sprite.width = 12;
		k->sprite.height = 10;
		if(destX > sprite.xPos)
		{
			k->sprite.xPos = sprite.xPos + 10;
			k->sprite.yPos = sprite.yPos + 10;
		}else{
			k->sprite.xPos = sprite.xPos - 10;
			k->sprite.yPos = sprite.yPos + 10;
		}
		float pX = xPos + rand() % 15;
		float pY = yPos + rand() % 15;
		float pDist = sqrt((sprite.xPos - pX)*(sprite.xPos - pX) +
			(sprite.yPos - pY)*(sprite.yPos - pY));
		k->xSpeed = ((xPos - sprite.xPos) / pDist) * 120.0f;
		k->ySpeed = ((yPos - sprite.yPos) / pDist) * 120.0f;
		k->texture = knifeTex;
		k->Setup();
		monsters->push_back(k);
	}else{
		//Decrement the attack timer and update animations 
		attackTimer -= m;
		float frame = attackTimer / 10.0f;
		frame *= textures.size();
		int f = textures.size() - ((int)frame + 1);
		if(f < 0)
			f = 0;
		//sprite.texture = textures[f];
	}

	return 0;
}

void Pirate::Setup()
{
	attackTimer = 0;
	destX = (rand() % 180) - 90;
	destY = (rand() % 180) - 90;
	speed = 36;
}
