// Robot.cpp: implementation of the Robot class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "Texture.h"
#include "Sprite.h"
#include "Zombie.h"
#include "Robot.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

Robot::Robot()
{

}

Robot::~Robot()
{

}

void Robot::Render()
{
	sprite.Render();
	flame.Render();
}

int Robot::Move(float xPos, float yPos)
{
	//Update the flame
	angle += m * 5.0f;
	flame.width = sin(angle) * 5.0f + 50;
	flame.height = sin(angle) * 5.0f + 10.0f;
	if(sprite.texture.uMax == -1)
	{
		flame.texture.uMax = -1;
		flame.xPos = sprite.xPos + 13 + (flame.width * 0.5f);
	}
	else
	{
		flame.texture.uMax = 1;
		flame.xPos = sprite.xPos - 13 - (flame.width * 0.5f);
	}
	flame.yPos = sprite.yPos - 3.5f;

	//Check for player/flame or zombie/flame collisions
	attackTimer -= m;
	if(Collide(flame, xPos, yPos) && attackTimer <= 0)
	{
		attackTimer = 0.5f;
		return 3;
	}
	for(int i = 0; i < monsters->size(); i++)
	{
		Monster* mon = monsters->at(i);
		if(mon->GetType() == 1)
		{
			if(Collide(flame, mon->sprite.xPos, mon->sprite.yPos) && attackTimer <= 0)
			{
				Zombie* z = (Zombie*)mon;
				z->bFire = true;
				z->speed = 36.0f;
				attackTimer = 0.1f;
			}
		}
	}

	//Move the robot
	float xDist = destX - sprite.xPos;
	float yDist = destY - sprite.yPos;
	float mag = sqrt(xDist*xDist + yDist*yDist);
	//Invert U coordinate if necessary
	if(destX > sprite.xPos)
	{
		sprite.texture.uMax = -1;
	}else{
		sprite.texture.uMax = 1;
	}
	//Change the point if it has been reached
	if(mag < speed * m)
	{
		sprite.xPos = destX;
		sprite.yPos = destY;
		destX = (rand() % 180) - 90;
		destY = (rand() % 180) - 90;
	}else{
		//Move
		xDist /= mag;
		yDist /= mag;
		sprite.xPos += xDist * speed * m;
		sprite.yPos += yDist * speed * m;
	}

	return 0;
}

void Robot::Setup()
{
	destX = (rand() % 180) - 90;
	destY = (rand() % 180) - 90;
	sprite.xPos = (rand() % 180) - 90;
	sprite.yPos = (rand() % 180) - 90;
	speed = 36.0f;
	attackTimer = 3.0f;
	angle = 0;
	flame.zDepth = 3;
}

int Robot::GetType()
{
	return 4;
}
