// Sprite.cpp: implementation of the Sprite class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "Texture.h"
#include "Sprite.h"
#include "Camera.h"

Sprite::Sprite()
{
	colour.r = colour.g = colour.b = colour.a = 255;
	visible = true;
	width = 10;
	height = 10;
	xPos = yPos = 0;
	rotation = 0;
	zDepth = 1;
}

Sprite::~Sprite()
{

}

void Sprite::Render()
{
	if(!visible)
		return;
	//Set the texture
	texture.Render();

	glPushMatrix();
		//Translate, scale, rotate
		glTranslatef(xPos, yPos, -zDepth);
		glScalef(width, height, 1);
		glRotatef(rotation, 0, 0, 1);

		//Set colour
		glColor4ub(colour.r, colour.g, colour.b, colour.a);

		//Render the quad
		glBegin(GL_QUADS);
			glTexCoord2f(texture.uMin, texture.vMax);
			glVertex3f(-0.5f, -0.5f, 0);
			glTexCoord2f(texture.uMin, texture.vMin);
			glVertex3f(-0.5f, 0.5f, 0);
			glTexCoord2f(texture.uMax, texture.vMin);
			glVertex3f(0.5f, 0.5f, 0);
			glTexCoord2f(texture.uMax, texture.vMax);
			glVertex3f(0.5f, -0.5f, 0);
		glEnd();
	glPopMatrix();
}

bool Sprite::Cull(Camera &cam)
{
	if(!visible)
		return false;
	float lFrustrum = cam.xPos - cam.viewWidth;
	float bFrustrum = cam.yPos - cam.viewHeight;
	float rFrustrum = cam.xPos + cam.viewWidth;
	float tFrustrum = cam.yPos + cam.viewHeight;

	//Left cull
	if(xPos + (width / 2.0f) < lFrustrum)
		return false;
	//Right cull
	if(xPos - (width / 2.0f) > rFrustrum)
		return false;
	//Bottom cull
	if(yPos + (height / 2.0f) < bFrustrum)
		return false;
	//Top cull
	if(yPos - (height / 2.0f) > tFrustrum)
		return false;

	return true;
}
