// Texture.cpp: implementation of the Texture class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "Texture.h"

Texture::Texture()
{
	uMin = 0;
	vMin = 0;
	uMax = 1;
	vMax = 1;
	textureID = 0;
}

Texture::~Texture()
{
	
}

void Texture::Render()
{
	if(textureID > 0)
	{
		glEnable(GL_TEXTURE_2D);
		glEnable(GL_ALPHA_TEST);
		glAlphaFunc(GL_GREATER, 0.0001f);
		glBindTexture(GL_TEXTURE_2D, textureID);
		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP);
		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
		glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
	}
}

bool Texture::Load(const char* file)
{
	Colour key;
	return Load(file, key);
}

bool Texture::Load(const char* file, Colour key)
{
	unsigned int id;
	ilGenImages(1, &id);
	ilBindImage(id);

	//Load the image from disk
	if(ilLoadImage((char*)file))
	{
		//Create the image and copy pixels
		ilConvertImage(IL_RGBA, IL_UNSIGNED_BYTE);
		int width = ilGetInteger(IL_IMAGE_WIDTH);
		int height = ilGetInteger(IL_IMAGE_HEIGHT);

		//Key the image
		Colour* pixels = (Colour*)ilGetData();
		for(unsigned int x = 0; x < width; x++)
		{
			for(unsigned int y = 0; y < height; y++)
			{
				if(pixels[y * width + x] == key)
					pixels[y * width + x].Set(0,0,0,0);
			}
		}
		
		//Create the OpenGL texture
		glGenTextures(1, &textureID);
		glEnable(GL_TEXTURE_2D);
		glBindTexture(GL_TEXTURE_2D, textureID);
		glTexImage2D(GL_TEXTURE_2D, 0, GL_UNSIGNED_BYTE, width, height,
			0, GL_UNSIGNED_BYTE, GL_RGBA, ilGetData());
		gluBuild2DMipmaps(GL_TEXTURE_2D, 4, width, height, GL_RGBA,
			GL_UNSIGNED_BYTE, ilGetData());

		//Free image space used by DevIL
		ilDeleteImages(1, &id);

		return true;
	}

	return false;
}

void Texture::Unload()
{
	if(textureID > 0)
		glDeleteTextures(1, &textureID);
}
