// Zombie.cpp: implementation of the Zombie class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "Sprite.h"
#include "Texture.h"
#include "Zombie.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

Zombie::Zombie()
{
	bFire = false;
}

Zombie::~Zombie()
{

}

int Zombie::Move(float xPos, float yPos)
{
	if(attackTimer <= 0)
	{
		//Calculate vector distance from player and normalize to get direction
		float xDist = xPos - sprite.xPos;
		float yDist = yPos - sprite.yPos;
		float mag = sqrt(xDist*xDist + yDist*yDist);

		if(mag < 25)
		{
			//Attack
			attackTimer = 10.0f;
		}else if(mag < 65)
		{
			//Move towards player
			xDist /= mag;
			yDist /= mag;
			sprite.xPos += xDist * speed * m;
			sprite.yPos += yDist * speed * m;
			//Invert U coordinate if necessary
			if(xPos > sprite.xPos)
			{
				sprite.texture.uMax = -1;
			}else{
				sprite.texture.uMax = 1;
			}
		}else{
			//Move towards random point
			xDist = destX - sprite.xPos;
			yDist = destY - sprite.yPos;
			mag = sqrt(xDist*xDist + yDist*yDist);
			//Invert U coordinate if necessary
			if(destX > sprite.xPos)
			{
				sprite.texture.uMax = -1;
			}else{
				sprite.texture.uMax = 1;
			}
			//Change the point if it has been reached
			if(mag < speed * m)
			{
				sprite.xPos = destX;
				sprite.yPos = destY;
				destX = (rand() % 180) - 90;
				destY = (rand() % 180) - 90;
			}else{
				//Move
				xDist /= mag;
				yDist /= mag;
				sprite.xPos += xDist * speed * m;
				sprite.yPos += yDist * speed * m;
			}
		}
	}else{
		//Decrement the attack timer, update animations and (possibly) do damage
		attackTimer -= 24.0f * m;
		if(attackTimer <= 0)
		{
			//Calculate vector distance from player and normalize to get direction
			float xDist = xPos - sprite.xPos;
			float yDist = yPos - sprite.yPos;
			float mag = sqrt(xDist*xDist + yDist*yDist);

			sprite.texture = zombieTex;

			if(mag < 25)
			{
				return bFire? 15 : 5;
			}
		}else
		{
			float frame = attackTimer / 10.0f;
			frame *= zombieAttack.size();
			int f = zombieAttack.size() - ((int)frame + 1);
			if(f < 0)
				f = 0;
			sprite.texture = zombieAttack[f];
		}
	}

	if(bFire)
	{
		if(sprite.texture.uMax == -1)
		{
			fire.xPos = sprite.xPos - 5;
		}else{
			fire.xPos = sprite.xPos + 5;
		}
		fire.yPos = sprite.yPos;
		fire.texture.uMin += m * 2;
		fire.texture.uMax += m * 2;
	}

	return 0;
}

void Zombie::Setup()
{
	bFire = false;
	fire.zDepth = sprite.zDepth + 1;
	fire.width = 20;
	fire.height = 45;
	destX = (rand() % 180) - 90;
	destY = (rand() % 180) - 90;
	attackTimer = 0;
	speed = 24.0f;
	sprite.texture = zombieTex;
}

int Zombie::GetType()
{
	return 1;
}

void Zombie::Render()
{
	sprite.Render();
	if(bFire)
		fire.Render();
}
